@@ -21,7 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef KWIN_SHOWFPS_H
 #define KWIN_SHOWFPS_H
 
-#include <QtCore/QTime>
+#include <QTime>
 
 #include <kwineffects.h>
 
@@ -99,6 +99,7 @@ private:
     QColor textColor;
     QRect fpsTextRect;
     int textAlign;
+    QScopedPointer<EffectFrame> m_noBenchmark;
 };
 
 } // namespace
