@@ -260,6 +260,7 @@ ColorCorrectionPrivate::ColorCorrectionPrivate(ColorCorrection *parent)
     : QObject(parent)
     , m_enabled(false)
     , m_hasError(false)
+    , m_duringEnablingPhase(false)
     , m_ccTextureUnit(-1)
     , m_dummyCCTexture(0)
     , m_lastOutput(-1)
@@ -313,13 +314,20 @@ bool ColorCorrection::setEnabled(bool enabled)
     if (enabled) {
         // Update all profiles and regions
         d->m_csi->update();
+        kDebug(1212) << "color correction will be enabled after contacting KolorManager";
+        d->m_duringEnablingPhase = true;
+        // d->m_enabled will be set to true in colorServerUpdateSucceededSlot()
     } else {
         d->deleteCCTextures();
+        d->m_enabled = false;
+        GLShader::sColorCorrect = false;
+        kDebug(1212) << "color correction has been disabled";
+
+        // Reload all shaders
+        ShaderManager::cleanup();
+        ShaderManager::instance();
     }
 
-    d->m_enabled = enabled;
-    GLShader::sColorCorrect = enabled;
-    kDebug(1212) << enabled;
     return true;
 }
 
@@ -330,9 +338,6 @@ void ColorCorrection::setupForOutput(int screen)
     if (!d->m_enabled || d->m_hasError)
         return;
 
-    // Clear any previous GL errors
-    checkGLError("setupForOutput-clearErrors");
-
     GLShader *shader = ShaderManager::instance()->getBoundShader();
     if (!shader) {
         kError(1212) << "no bound shader for color correction setup";
@@ -347,13 +352,12 @@ void ColorCorrection::setupForOutput(int screen)
         d->m_ccTextureUnit = maxUnits - 1;
     }
 
-    if (!shader->setUniform("u_ccLookupTexture", d->m_ccTextureUnit)) {
+    if (!shader->setUniform(GLShader::ColorCorrectionLookupTextureUnit, d->m_ccTextureUnit)) {
         kError(1212) << "unable to set uniform for the color correction lookup texture";
         d->m_hasError = true;
         emit errorOccured();
         return;
     }
-    checkGLError("setupForOutput-setUniform");
 
     if (!d->setupCCTextures()) {
         kError(1212) << "unable to setup color correction textures";
@@ -377,13 +381,6 @@ void ColorCorrection::setupForOutput(int screen)
 
     glActiveTexture(activeTexture);
 
-    if (checkGLError("setupForOutput")) {
-        kError(1212) << "GL error while setting up color correction for output" << screen;
-        d->m_hasError = true;
-        emit errorOccured();
-        return;
-    }
-
     d->m_lastOutput = screen;
 }
 
@@ -577,9 +574,6 @@ bool ColorCorrectionPrivate::setupCCTextures()
         return false;
     }
 
-    // Clear any previous GL errors
-    checkGLError("setupCCTextures-clearErrors");
-
     // Dummy texture first
     if (!m_dummyCCTexture) {
         glGenTextures(1, &m_dummyCCTexture);
@@ -607,7 +601,6 @@ bool ColorCorrectionPrivate::setupCCTextures()
             }
     }
 
-    success = success && !checkGLError("setupCCTextures");
     return success;
 }
 
@@ -665,6 +658,18 @@ void ColorCorrectionPrivate::colorServerUpdateSucceededSlot()
     // Force the color correction textures to be recreated
     deleteCCTextures();
 
+    // If this is reached after enabling color correction using ColorCorrection::setEnabled(true)
+    if (m_duringEnablingPhase) {
+        m_duringEnablingPhase = false;
+        m_enabled = true;
+        GLShader::sColorCorrect = true;
+        kDebug(1212) << "Color correction has been enabled";
+
+        // Reload all shaders
+        ShaderManager::cleanup();
+        ShaderManager::instance();
+    }
+
     emit q->changed();
 }
 
@@ -672,9 +677,11 @@ void ColorCorrectionPrivate::colorServerUpdateFailedSlot()
 {
     Q_Q(ColorCorrection);
 
-    kError(1212) << "Update of color profiles failed";
+    m_duringEnablingPhase = false;
 
-    q->setEnabled(false);
+    kError(1212) << "Update of color profiles failed";
+    m_hasError = true;
+    emit q->errorOccured();
 }
 
 } // KWin namespace
