@@ -196,6 +196,7 @@ public:
 
     enum IntUniform {
         AlphaToOne,     ///< @deprecated no longer used
+        ColorCorrectionLookupTextureUnit,
         IntUniformCount
     };
 
@@ -237,6 +238,7 @@ private:
     static bool sColorCorrect;
 
     friend class ColorCorrection;
+    friend class ColorCorrectionPrivate;
     friend class ShaderManager;
 };
 
@@ -578,7 +580,6 @@ private:
     static bool sSupported;
     static bool s_blitSupported;
     static QStack<GLRenderTarget*> s_renderTargets;
-    static QSize s_oldViewport;
 
     GLTexture mTexture;
     bool mValid;
