@@ -79,36 +79,21 @@ public Q_SLOTS:
 
     void loadProfile(bool force = false);
 
-    int brightness() const;
-    void setBrightness(int percent);
-
     qulonglong batteryRemainingTime() const;
 
-    void increaseBrightness();
-    void decreaseBrightness();
-
-    void suspendToRam();
-    void suspendToDisk();
-    void suspendHybrid();
-
-    void onResumeFromSuspend();
-
     bool isLidClosed();
+    bool isActionSupported(const QString &actionName);
 
 Q_SIGNALS:
     void coreReady();
     void profileChanged(const QString &newProfile);
     void configurationReloaded();
-    void brightnessChanged(int percent);
     void batteryRemainingTimeChanged(qulonglong time);
-    void resumingFromSuspend();
 
 private:
     void registerActionTimeout(Action *action, int timeout);
     void unregisterActionTimeouts(Action *action);
 
-    void triggerSuspendSession(uint action);
-
     friend class Action;
 
     BackendInterface *m_backend;
@@ -142,14 +127,12 @@ private Q_SLOTS:
     void onAcAdapterStateChanged(PowerDevil::BackendInterface::AcAdapterState);
     void onBatteryChargePercentChanged(int,const QString&);
     void onBatteryChargeStateChanged(int,const QString&);
-    void onBrightnessChanged(float);
     void onBatteryRemainingTimeChanged(qulonglong);
     void onKIdleTimeoutReached(int,int);
     void onResumingFromIdle();
     void onDeviceAdded(const QString &udi);
     void onDeviceRemoved(const QString &udi);
     void onCriticalBatteryTimerExpired();
-    void powerOffButtonTriggered();
 };
 
 }
